@@ -483,12 +483,6 @@ command_set_config(DBus::Connection* conn, Snapper* snapper)
 	string key = boost::trim_copy(arg.substr(0, pos));
 	string value = boost::trim_copy(arg.substr(pos + 1));
 
-	if (key.empty())
-	{
-	    cerr << _("Invalid configdata.") << endl;
-	    exit(EXIT_FAILURE);
-	}
-
 	raw[key] = value;
     }
 
@@ -582,6 +576,7 @@ command_list(DBus::Connection* conn, Snapper* snapper)
 		    row.add(decString(it1->getNum()));
 		    row.add(it1->getType() == POST ? decString(it1->getPreNum()) : "");
 		    row.add(it1->isCurrent() ? "" : datetime(it1->getDate(), false, false));
+		    row.add(username(it1->getUid()));
 		    row.add(it1->getCleanup());
 		    row.add(it1->getDescription());
 		    row.add(show_userdata(it1->getUserdata()));
@@ -629,6 +624,7 @@ command_list(DBus::Connection* conn, Snapper* snapper)
 		    TableRow row;
 		    row.add(decString(it1->getNum()));
 		    row.add(it1->isCurrent() ? "" : datetime(it1->getDate(), false, false));
+		    row.add(username(it1->getUid()));
 		    row.add(it1->getDescription());
 		    row.add(show_userdata(it1->getUserdata()));
 		    table.add(row);
@@ -1362,6 +1358,12 @@ command_cleanup(DBus::Connection* conn, Snapper* snapper)
 }
 
 
+void
+help_debug()
+{
+}
+
+
 void
 command_debug(DBus::Connection* conn, Snapper* snapper)
 {
@@ -1491,10 +1493,7 @@ help()
 	 << endl;
 
     for (list<Cmd>::const_iterator cmd = cmds.begin(); cmd != cmds.end(); ++cmd)
-    {
-	if (cmd->help_func)
-	    (*cmd->help_func)();
-    }
+	(*cmd->help_func)();
 
     exit (EXIT_SUCCESS);
 }
@@ -1526,7 +1525,7 @@ main(int argc, char** argv)
 #endif
     cmds.push_back(Cmd("undochange", command_undo, help_undo, false, true));
     cmds.push_back(Cmd("cleanup", command_cleanup, help_cleanup, false, true));
-    cmds.push_back(Cmd("debug", command_debug, NULL, false, false));
+    cmds.push_back(Cmd("debug", command_debug, help_debug, false, false));
 
     const struct option options[] = {
 	{ "quiet",		no_argument,		0,	'q' },
@@ -1666,6 +1665,8 @@ main(int argc, char** argv)
 		cerr << _("No permissions.") << endl;
 	    else if (name == "error.invalid_userdata")
 		cerr << _("Invalid userdata.") << endl;
+	    else if (name == "error.invalid_configdata")
+		cerr << _("Invalid configdata.") << endl;
 	    else if (name == "error.illegal_snapshot")
 		cerr << _("Illegal Snapshot.") << endl;
 	    else if (name == "error.config_locked")
