@@ -27,7 +27,7 @@
  * Add the following line to /etc/pam.d/common-session:
  *      "session optional pam_snapper.so"
  *
- * See "man pam_snapper" and "map snapper" for more information.
+ * See "man pam_snapper" and "man snapper" for more information.
  *
  * @section Related Projects
  *
@@ -373,20 +373,20 @@ static int forker( pam_handle_t * pamh, const char *pam_user, uid_t uid, gid_t g
 
 		if ( setgid( gid ) != 0 || initgroups( pam_user, gid ) != 0 || setuid( uid ) != 0 ) {
 			munmap( p, sizeof( *snapshot_num_out ) );
-			exit( EXIT_FAILURE );
+			_exit( EXIT_FAILURE );
 		}
 
 		if ( cdbus_create_snapshot( snapper_conf, createmode, cleanup, num_user_data,
 					    user_data, snapshot_num_in, snapshot_num_out ) != 0 ) {
 			munmap( p, sizeof( *snapshot_num_out ) );
-			exit( EXIT_FAILURE );
+			_exit( EXIT_FAILURE );
 		}
 
 		memcpy( p, snapshot_num_out, sizeof( *snapshot_num_out ) );
 
 		munmap( p, sizeof( *snapshot_num_out ) );
 
-		exit( EXIT_SUCCESS );
+		_exit( EXIT_SUCCESS );
 
 	} else if ( child > 0 ) {
 
@@ -494,17 +494,22 @@ static int worker( pam_handle_t * pamh, const char *pam_user, const char *snappe
 		     ( pamh, "pam_snapper_snapshot_num",
 		       ( const void ** )&snapshot_num_in ) != PAM_SUCCESS ) {
 			pam_syslog( pamh, LOG_ERR, "getting previous snapshot_num failed" );
+			free( snapshot_num_out );
 			return -1;
 		}
 	}
 
 	if ( forker( pamh, pam_user, uid, gid, snapper_conf, createmode, cleanup, num_user_data,
 		     user_data, snapshot_num_in, snapshot_num_out ) != 0 )
+	{
+		free( snapshot_num_out );
 		return -1;
+	}
 
 	if ( pam_set_data
 	     ( pamh, "pam_snapper_snapshot_num", snapshot_num_out,
 	       cleanup_snapshot_num ) != PAM_SUCCESS ) {
+		free( snapshot_num_out );
 		pam_syslog( pamh, LOG_ERR, "pam_set_data failed" );
 	}
 
