@@ -177,6 +177,10 @@ Client::introspect(DBus::Connection& conn, DBus::Message& msg)
 	"      <arg name='config-name' type='s'/>\n"
 	"    </signal>\n"
 
+	"    <signal name='ConfigModified'>\n"
+	"      <arg name='config-name' type='s'/>\n"
+	"    </signal>\n"
+
 	"    <signal name='ConfigDeleted'>\n"
 	"      <arg name='config-name' type='s'/>\n"
 	"    </signal>\n"
@@ -191,7 +195,7 @@ Client::introspect(DBus::Connection& conn, DBus::Message& msg)
 	"      <arg name='number' type='u'/>\n"
 	"    </signal>\n"
 
-	"    <signal name='SnapshotDeleted'>\n"
+	"    <signal name='SnapshotsDeleted'>\n"
 	"      <arg name='config-name' type='s'/>\n"
 	"      <arg name='number' type='u'/>\n"
 	"    </signal>\n"
@@ -205,6 +209,11 @@ Client::introspect(DBus::Connection& conn, DBus::Message& msg)
 	"      <arg name='data' type='(ssa{ss})' direction='out'/>\n"
 	"    </method>\n"
 
+	"    <method name='SetConfig'>\n"
+	"      <arg name='config-name' type='s' direction='in'/>\n"
+	"      <arg name='data' type='a{ss}' direction='in'/>\n"
+	"    </method>\n"
+
 	"    <method name='CreateConfig'>\n"
 	"      <arg name='config-name' type='s' direction='in'/>\n"
 	"      <arg name='subvolume' type='s' direction='in'/>\n"
@@ -431,6 +440,18 @@ Client::signal_config_created(DBus::Connection& conn, const string& config_name)
 }
 
 
+void
+Client::signal_config_modified(DBus::Connection& conn, const string& config_name)
+{
+    DBus::MessageSignal msg(PATH, INTERFACE, "ConfigModified");
+
+    DBus::Hoho hoho(msg);
+    hoho << config_name;
+
+    conn.send(msg);
+}
+
+
 void
 Client::signal_config_deleted(DBus::Connection& conn, const string& config_name)
 {
@@ -501,7 +522,7 @@ Client::list_configs(DBus::Connection& conn, DBus::Message& msg)
     DBus::Hoho hoho(reply);
     hoho.open_array(DBus::TypeInfo<ConfigInfo>::signature);
     for (MetaSnappers::const_iterator it = meta_snappers.begin(); it != meta_snappers.end(); ++it)
-	hoho << it->config_info;
+	hoho << it->getConfigInfo();
     hoho.close_array();
 
     conn.send(reply);
@@ -527,12 +548,39 @@ Client::get_config(DBus::Connection& conn, DBus::Message& msg)
     DBus::MessageMethodReturn reply(msg);
 
     DBus::Hoho hoho(reply);
-    hoho << it->config_info;
+    hoho << it->getConfigInfo();
 
     conn.send(reply);
 }
 
 
+void
+Client::set_config(DBus::Connection& conn, DBus::Message& msg)
+{
+    string config_name;
+
+    DBus::Hihi hihi(msg);
+    map<string, string> raw;
+    hihi >> config_name >> raw;
+
+    y2deb("SetConfig config_name:" << config_name << " raw:" << raw);
+
+    boost::shared_lock<boost::shared_mutex> lock(big_mutex);
+
+    MetaSnappers::iterator it = meta_snappers.find(config_name);
+
+    check_permission(conn, msg);
+
+    it->setConfigInfo(raw);
+
+    DBus::MessageMethodReturn reply(msg);
+
+    conn.send(reply);
+
+    signal_config_modified(conn, config_name);
+}
+
+
 void
 Client::create_config(DBus::Connection& conn, DBus::Message& msg)
 {
@@ -762,10 +810,7 @@ Client::set_snapshot(DBus::Connection& conn, DBus::Message& msg)
     if (snap == snapshots.end())
 	throw IllegalSnapshotException();
 
-    snap->setDescription(description);
-    snap->setCleanup(cleanup);
-    snap->setUserdata(userdata);
-    snap->flushInfo();
+    snapper->modifySnapshot(snap, description, cleanup, userdata);
 
     DBus::MessageMethodReturn reply(msg);
 
@@ -797,11 +842,8 @@ Client::create_single_snapshot(DBus::Connection& conn, DBus::Message& msg)
 
     Snapper* snapper = it->getSnapper();
 
-    Snapshots::iterator snap1 = snapper->createSingleSnapshot(description);
-    snap1->setUid(conn.get_unix_userid(msg));
-    snap1->setCleanup(cleanup);
-    snap1->setUserdata(userdata);
-    snap1->flushInfo();
+    Snapshots::iterator snap1 = snapper->createSingleSnapshot(conn.get_unix_userid(msg),
+							      description, cleanup, userdata);
 
     DBus::MessageMethodReturn reply(msg);
 
@@ -836,11 +878,8 @@ Client::create_pre_snapshot(DBus::Connection& conn, DBus::Message& msg)
 
     Snapper* snapper = it->getSnapper();
 
-    Snapshots::iterator snap1 = snapper->createPreSnapshot(description);
-    snap1->setUid(conn.get_unix_userid(msg));
-    snap1->setCleanup(cleanup);
-    snap1->setUserdata(userdata);
-    snap1->flushInfo();
+    Snapshots::iterator snap1 = snapper->createPreSnapshot(conn.get_unix_userid(msg), description,
+							   cleanup, userdata);
 
     DBus::MessageMethodReturn reply(msg);
 
@@ -879,14 +918,12 @@ Client::create_post_snapshot(DBus::Connection& conn, DBus::Message& msg)
 
     Snapshots::iterator snap1 = snapshots.find(pre_num);
 
-    Snapshots::iterator snap2 = snapper->createPostSnapshot(description, snap1);
-    snap2->setUid(conn.get_unix_userid(msg));
-    snap2->setCleanup(cleanup);
-    snap2->setUserdata(userdata);
-    snap2->flushInfo();
+    Snapshots::iterator snap2 = snapper->createPostSnapshot(snap1, conn.get_unix_userid(msg),
+							    description, cleanup, userdata);
 
-    bool tmp;
-    if (it->config_info.getValue("BACKGROUND_COMPARISON", tmp) && tmp)
+    bool background_comparison = true;
+    it->getConfigInfo().getValue("BACKGROUND_COMPARISON", background_comparison);
+    if (background_comparison)
 	backgrounds.add_task(it, snap1, snap2);
 
     DBus::MessageMethodReturn reply(msg);
@@ -1222,6 +1259,8 @@ Client::dispatch(DBus::Connection& conn, DBus::Message& msg)
 	    create_config(conn, msg);
 	else if (msg.is_method_call(INTERFACE, "GetConfig"))
 	    get_config(conn, msg);
+	else if (msg.is_method_call(INTERFACE, "SetConfig"))
+	    set_config(conn, msg);
 	else if (msg.is_method_call(INTERFACE, "DeleteConfig"))
 	    delete_config(conn, msg);
 	else if (msg.is_method_call(INTERFACE, "LockConfig"))
@@ -1338,6 +1377,11 @@ Client::dispatch(DBus::Connection& conn, DBus::Message& msg)
 	DBus::MessageError reply(msg, "error.unknown_file", DBUS_ERROR_FAILED);
 	conn.send(reply);
     }
+    catch (const InvalidConfigdataException& e)
+    {
+	DBus::MessageError reply(msg, "error.invalid_configdata", DBUS_ERROR_FAILED);
+	conn.send(reply);
+    }
     catch (const InvalidUserdataException& e)
     {
 	DBus::MessageError reply(msg, "error.invalid_userdata", DBUS_ERROR_FAILED);
