@@ -72,6 +72,7 @@ public:
     void check_snapshot_in_use(const MetaSnapper& meta_snapper, unsigned int number) const;
 
     void signal_config_created(DBus::Connection& conn, const string& config_name);
+    void signal_config_modified(DBus::Connection& conn, const string& config_name);
     void signal_config_deleted(DBus::Connection& conn, const string& config_name);
     void signal_snapshot_created(DBus::Connection& conn, const string& config_name,
 				 unsigned int num);
@@ -82,6 +83,7 @@ public:
 
     void list_configs(DBus::Connection& conn, DBus::Message& msg);
     void get_config(DBus::Connection& conn, DBus::Message& msg);
+    void set_config(DBus::Connection& conn, DBus::Message& msg);
     void create_config(DBus::Connection& conn, DBus::Message& msg);
     void delete_config(DBus::Connection& conn, DBus::Message& msg);
     void lock_config(DBus::Connection& conn, DBus::Message& msg);
