@@ -49,7 +49,7 @@ namespace snapper
 	const string& getConfigName() const { return config_name; }
 	const string& getSubvolume() const { return subvolume; }
 
-	virtual void setValue(const string& key, const string& value);
+	virtual void checkKey(const string& key) const;
 
     private:
 
@@ -113,7 +113,7 @@ namespace snapper
 	Snapper(const string& config_name = "root", bool disable_filters = false);
 	~Snapper();
 
-	string configName() const { return config_name; }
+	string configName() const { return config_info->getConfigName(); }
 
 	string subvolumeDir() const;
 
@@ -125,9 +125,22 @@ namespace snapper
 
 	Snapshots::const_iterator getSnapshotCurrent() const;
 
-	Snapshots::iterator createSingleSnapshot(string description);
-	Snapshots::iterator createPreSnapshot(string description);
-	Snapshots::iterator createPostSnapshot(string description, Snapshots::const_iterator pre);
+	Snapshots::iterator createSingleSnapshot(string description) __attribute__ ((deprecated));
+	Snapshots::iterator createPreSnapshot(string description) __attribute__ ((deprecated));
+	Snapshots::iterator createPostSnapshot(string description, Snapshots::const_iterator pre) __attribute__ ((deprecated));
+
+	Snapshots::iterator createSingleSnapshot(uid_t uid, const string& description,
+						 const string& cleanup,
+						 const map<string, string>& userdata);
+	Snapshots::iterator createPreSnapshot(uid_t uid, const string& description,
+					      const string& cleanup,
+					      const map<string, string>& userdata);
+	Snapshots::iterator createPostSnapshot(Snapshots::const_iterator pre, uid_t uid,
+					       const string& description, const string& cleanup,
+					       const map<string, string>& userdata);
+
+	void modifySnapshot(Snapshots::iterator snapshot, const string& description,
+			    const string& cleanup, const map<string, string>& userdata);
 
 	void deleteSnapshot(Snapshots::iterator snapshot);
 
@@ -143,8 +156,6 @@ namespace snapper
 
 	const Filesystem* getFilesystem() const { return filesystem; }
 
-	const SysconfigFile* getSysconfigFile() const { return config; }
-
     private:
 
 	void filter1(list<Snapshots::iterator>& tmp, time_t min_age);
@@ -152,11 +163,7 @@ namespace snapper
 
 	void loadIgnorePatterns();
 
-	const string config_name;
-
-	SysconfigFile* config;
-
-	string subvolume;
+	ConfigInfo* config_info;
 
 	Filesystem* filesystem;
 
